@@ -3,7 +3,7 @@ import os
 from django.conf import settings
 from django.core.management.base import BaseCommand
 
-from ckeditor_uploader.backends import registry
+from ckeditor_uploader.backends import get_backend
 from ckeditor_uploader.utils import get_thumb_filename
 from ckeditor_uploader.views import get_image_files
 
@@ -16,16 +16,14 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         if getattr(settings, "CKEDITOR_IMAGE_BACKEND", None):
-            backend = registry.get_backend()
+            backend = get_backend()
             for image in get_image_files():
                 if not self._thumbnail_exists(image):
                     self.stdout.write("Creating thumbnail for %s" % image)
                     try:
                         backend.create_thumbnail(image)
                     except Exception as e:
-                        self.stdout.write(
-                            "Couldn't create thumbnail for %s: %s" % (image, e)
-                        )
+                        self.stdout.write(f"Couldn't create thumbnail for {image}: {e}")
             self.stdout.write("Finished")
         else:
             self.stdout.write("No thumbnail backend is enabled")
